@@ -65,6 +65,11 @@ static const char *const initcoms [] = {
 	NULL
 };
 
+static int initio_done;
+
+static struct env env;
+struct env *e = &env;
+
 int
 main(int argc, char **argv)
 {
@@ -260,23 +265,21 @@ main(int argc, char **argv)
 		if (argv[argi])
 			poshname = argv[argi++];
 	} else if (argi < argc && !Flag(FSTDIN)) {
+		struct stat statb;
+
 		s = pushs(SFILE, ATEMP);
-#ifdef OS2
-		/* a bug in os2 extproc shell processing doesn't
-		 * pass full pathnames so we have to search for it.
-		 * This changes the behavior of 'ksh arg' to search
-		 * the users search path but it can't be helped.
-		 */
-		s->file = search(argv[argi++], path, R_OK, (int *) 0);
-		if (!s->file || !*s->file)
-		        s->file = argv[argi - 1];
-#else
 		s->file = argv[argi++];
-#endif /* OS2 */
 		s->u.shf = shf_open(s->file, O_RDONLY, 0, SHF_MAPHI|SHF_CLEXEC);
 		if (s->u.shf == NULL) {
+			shl_stdout_ok = 0;
+			warningf(TRUE, "%s: %s", s->file, strerror(errno));
 			exstat = 127; /* POSIX */
-			errorf("%s: %s", s->file, strerror(errno));
+			unwind(LERROR);
+		} else if (fstat(s->u.shf->fd,&statb)<0 || S_ISDIR(statb.st_mode)) {
+			shl_stdout_ok = 0;
+			warningf(TRUE, "%s is a directory", s->file);
+			exstat = 126; /* POSIX? */
+			unwind(LERROR);
 		}
 		poshname = s->file;
 	} else {
@@ -303,9 +306,8 @@ main(int argc, char **argv)
 	}
 
 	/* initialize job control */
-	i = Flag(FMONITOR) != 127;
 	Flag(FMONITOR) = 0;
-	j_init(i);
+	j_init();
 #ifdef EDIT
 	/* Do this after j_init(), as tty_fd is not initialized 'til then */
 	if (Flag(FTALKING))
@@ -470,6 +472,8 @@ shell(s, toplevel)
 	volatile int interactive = Flag(FTALKING) && toplevel;
 	int i;
 
+	s->flags |= SF_FIRST;	/* enable UTF-8 BOM check */
+
 	newenv(E_PARSE);
 	if (interactive)
 		really_exit = 0;
@@ -553,7 +557,7 @@ shell(s, toplevel)
 		}
 
 		if (t && (!Flag(FNOEXEC) || (s->flags & SF_TTY)))
-			exstat = execute(t, 0);
+			exstat = execute(t, 0, NULL);
 
 		if (t != NULL && t->type != TEOF && interactive && really_exit)
 			really_exit = 0;
