@@ -445,10 +445,10 @@ gmatchx(const char *s, const char *p, int isfile)
 		char *t = len <= sizeof(tbuf) ? tbuf :
 		    (char *) alloc(len, ATEMP);
 		debunk(t, p, len);
-		return !strcmp(t, s);
+		return (!strcmp(t, s));
 	}
-	return do_gmatch((const unsigned char *) s, (const unsigned char *) se,
-	    (const unsigned char *) p, (const unsigned char *) pe);
+	return (do_gmatch((const unsigned char *) s, (const unsigned char *) se,
+	    (const unsigned char *) p, (const unsigned char *) pe));
 }
 
 /* Returns if p is a syntacticly correct globbing pattern, false
@@ -495,10 +495,10 @@ has_globbing(const char *xp, const char *xpe)
 		} else if (c == ']') {
 			if (in_bracket) {
 				if (bnest)		/* [a*(b]) */
-					return 0;
+					return (0);
 				in_bracket = 0;
 			}
-		} else if ((c & 0x80) && strchr("*+?@! ", c & 0x7f)) {
+		} else if ((c & 0x80) && strchr("*? ", c & 0x7f)) {
 			saw_glob = 1;
 			if (in_bracket)
 				bnest++;
@@ -506,18 +506,18 @@ has_globbing(const char *xp, const char *xpe)
 				nest++;
 		} else if (c == '|') {
 			if (in_bracket && !bnest)	/* *(a[foo|bar]) */
-				return 0;
+				return (0);
 		} else if (c == /*(*/ ')') {
 			if (in_bracket) {
 				if (!bnest--)		/* *(a[b)c] */
-					return 0;
+					return (0);
 			} else if (nest)
 				nest--;
 		}
 		/* else must be a MAGIC-MAGIC, or MAGIC-!, MAGIC--, MAGIC-]
 			 MAGIC-{, MAGIC-,, MAGIC-} */
 	}
-	return saw_glob && !in_bracket && !nest;
+	return (saw_glob && !in_bracket && !nest);
 }
 
 /* Function must return either 0 or 1 (assumed by code for 0x80|'!') */
