@@ -20,7 +20,7 @@ CPP="${1-cc -E}"
  echo '#include "sh.h"';
  echo '	{ QwErTy SIGNALS , "DUMMY" , "hook for number of signals" },';
  sed -e '/^[	 ]*#/d' -e 's/^[	 ]*\([^ 	][^ 	]*\)[	 ][	 ]*\(.*[^ 	]\)[ 	]*$/#ifdef SIG\1\
-	{ QwErTy SIG\1 , "\1", "\2" },\
+	{ QwErTy SIG\1 , "\1", "\2", 0, 0, 0, 0, 0 },\
 #endif/') > $in
 $CPP $in  > $out
 sed -n 's/{ QwErTy/{/p' < $out | awk '{print NR, $0}' | sort -k 3n,1n |
@@ -31,7 +31,7 @@ sed -n 's/{ QwErTy/{/p' < $out | awk '{print NR, $0}' | sort -k 3n,1n |
 		n = $2;
 		if (n > 0 && n != last) {
 		    while (++last < n) {
-			printf "\t{ %d , (char *) 0, `Signal %d` } ,\n", last, last;
+			printf "\t{ %d , (char *) 0, `Signal %d`, 0, 0, 0, 0, 0 } ,\n", last, last;
 		    }
 		    print;
 		}
