@@ -501,6 +501,7 @@ static void ers_walk(const void *nodep, const VISIT which, const int UNUSED(dept
 				if ((vp->flag&ARRAY) && any_set && !(vp->flag & ISSET))
 					return;
 				/* no arguments */
+#if 0
 				if (!(flagstmp & POSH_BUILTIN_SET)) {
 					/* at&t ksh prints things like export, integer,
 					 * leftadj, zerofill, etc., but POSIX says must
@@ -511,6 +512,7 @@ static void ers_walk(const void *nodep, const VISIT which, const int UNUSED(dept
 					else if ((vp->flag&RDONLY) && (flagstmp & POSH_BUILTIN_READONLY))
 						shprintf("readonly %s\n", vp->name);
 				} else {
+#endif
 					if (pflagtmp)
 						shprintf("%s ",
 								(flagtmp & EXPORT) ?  "export" : "readonly");
@@ -518,7 +520,7 @@ static void ers_walk(const void *nodep, const VISIT which, const int UNUSED(dept
 						shprintf("%s[%d]", vp->name, vp->index);
 					else
 						shprintf("%s", vp->name);
-					if (vp->flag&ISSET) {
+					if (vp->flag&ISSET && pflagtmp) {
 						char *s = str_val(vp);
 
 						shprintf("=");
@@ -526,7 +528,9 @@ static void ers_walk(const void *nodep, const VISIT which, const int UNUSED(dept
 						shprintf("%s", s);
 					}
 					shprintf("\n");
+#if 0
 				}
+#endif
 				/* Only report first `element' of an array with
 				 * no set elements.
 				 */
@@ -541,8 +545,7 @@ int posh_builtin_exportreadonlyset(int argc, char **argv, int flags)
 {
 	struct block *l = e->loc;
 	Tflag fset = 0, fclr = 0;
-	char *fieldstr, *basestr;
-	int field, base, optc;
+	int optc;
 	Tflag flag;
 	int pflag = 0;
 
@@ -551,8 +554,6 @@ int posh_builtin_exportreadonlyset(int argc, char **argv, int flags)
 	if(flags & POSH_BUILTIN_READONLY)
  		fset |= RDONLY;
 
-	fieldstr = basestr = (char *) 0;
-
 	optind = 0;
 
 	while ((optc = getopt(argc, argv, "p")) != -1) {
@@ -565,20 +566,13 @@ int posh_builtin_exportreadonlyset(int argc, char **argv, int flags)
 		}
 	}
 
-	field = 0;
-	if (fieldstr && !bi_getn(fieldstr, &field))
-		return 1;
-	base = 0;
-	if (basestr && !bi_getn(basestr, &base))
-		return 1;
-
 	/* set variables and attributes */
 	if (argv[optind]) {
 		int i;
 		int rval = 0;
 
 		for (i = optind; argv[i]; i++) {
-			if (!typeset(argv[i], fset, fclr, field, base)) {
+			if (!typeset(argv[i], fset, fclr, 0, 0)) {
 				bi_errorf("%s: not identifier", argv[i]);
 				return 1;
 			}
@@ -608,16 +602,11 @@ int posh_builtin_local(int argc, char **argv, int UNUSED(flags))
 
 	for (i = 1; i < argc; i++) {
 		for (p = argv[i]; *p; p++) {
-			if (!isalnum(*p) && (*p!='_')) {
+			if (!typeset(argv[i], LOCAL, 0, 0, 0)) {
 				bi_errorf("%s: not identifier", argv[i]);
 				return 1;
 			}
 		}
-
-		if(!local(argv[i], 0)) {
-			bi_errorf("%s: error making local", argv[i]);
-			return 1;
-		}
 	}
 
 	return 0;
@@ -664,22 +653,22 @@ int posh_builtin_getopts(int UNUSED(argc), char **argv, int UNUSED(flags))
 	options = *wp++;
 	if (!options) {
 		bi_errorf("missing options argument");
-		return 1;
+		return (1);
 	}
 
 	var = *wp++;
 	if (!var) {
 		bi_errorf("missing name argument");
-		return 1;
+		return (1);
 	}
 	if (!*var || *skip_varname(var, TRUE)) {
 		bi_errorf("%s: is not an identifier", var);
-		return 1;
+		return (1);
 	}
 
-	if (e->loc->next == (struct block *) 0) {
+	if (e->loc->next == NULL) {
 		internal_errorf(0, "posh_builtin_getopts: no argv");
-		return 1;
+		return (1);
 	}
 
 	noerror = (options[0] == ':') ? 1 : 0;
@@ -688,7 +677,7 @@ int posh_builtin_getopts(int UNUSED(argc), char **argv, int UNUSED(flags))
 		options++;
 
 	/* Which arguments are we parsing... */
-	if (*wp == (char *) 0)
+	if (*wp == NULL)
 		wp = e->loc->next->argv;
 	else
 		*--wp = e->loc->next->argv[0];
@@ -738,7 +727,7 @@ int posh_builtin_getopts(int UNUSED(argc), char **argv, int UNUSED(flags))
 
 	uoptind = optind;
 
-	return optc < 0 ? 1 : ret;
+	return (optc < 0 ? 1 : ret);
 }
 
 int posh_builtin_kill(int argc, char **argv, int UNUSED(flags))
