@@ -130,7 +130,7 @@ initvar()
 
 	specials_root = NULL;
 	for (i = 0; names[i].name; i++) {
-		tp = transitional_tenter((void **)&specials_root, names[i].name);
+		tp = transitional_tenter((void **)&specials_root, names[i].name, APERM);
 		tp->flag = DEFINED|ISSET;
 		tp->type = names[i].v;
 	}
@@ -241,7 +241,7 @@ global(const char *n)
 		if (l->next == NULL)
 			break;
 	}
-	vp = transitional_tenter(&l->vars.root, n);
+	vp = transitional_tenter(&l->vars.root, n, APERM);
 	if (array)
 		vp = arraysearch(vp, val);
 	vp->flag |= DEFINED;
@@ -254,9 +254,7 @@ global(const char *n)
  * Search for local variable, if not found create locally.
  */
 struct tbl *
-local(n, copy)
-	register const char *n;
-	bool_t copy;
+local(const char *n, bool_t copy)
 {
 	register struct block *l = e->loc;
 	register struct tbl *vp;
@@ -272,8 +270,7 @@ local(n, copy)
 		vp->areap = ATEMP;
 		return vp;
 	}
-	vp = transitional_tenter(&l->vars.root, n);
-	vp->areap = ATEMP;
+	vp = transitional_tenter(&l->vars.root, n, &l->area);
 	if (copy && !(vp->flag & DEFINED)) {
 		struct block *ll = l;
 		struct tbl *vq = (struct tbl *) 0;
